@@ -48,6 +48,7 @@
 #include <QScreen>
 #include <QTimer>
 #include <QtMath>
+#include <qobjectdefs.h>
 #include <utility>
 
 SpectacleCore *SpectacleCore::s_self = nullptr;
@@ -107,6 +108,7 @@ SpectacleCore::SpectacleCore(QObject *parent)
 
     m_platform = loadPlatform();
     m_videoPlatform = loadVideoPlatform();
+    m_videoPlatform->setExtension(Settings::videoFormat());
     auto platform = m_platform.get();
     m_annotationDocument = std::make_unique<AnnotationDocument>(new AnnotationDocument(this));
 
@@ -115,13 +117,17 @@ SpectacleCore::SpectacleCore(QObject *parent)
     connect(this, &SpectacleCore::grabDone, this, [this](const QImage &image,
                                                          const ExportManager::Actions &actions){
         deleteWindows();
-        const auto &exportActions = actions == ExportManager::NoActions ? autoExportActions() : actions;
-        onScreenshotUpdated(image, exportActions);
+        onScreenshotUpdated(image);
+        syncExportImage();
+        const auto &exportActions = actions & ExportManager::AnyAction ? actions : autoExportActions();
+        ExportManager::instance()->exportImage(exportActions, outputUrl());
     });
 
     connect(platform, &Platform::newScreenshotTaken, this, [this](const QImage &image){
         m_annotationDocument->clearAnnotations();
-        onScreenshotUpdated(image, autoExportActions());
+        onScreenshotUpdated(image);
+        syncExportImage();
+        ExportManager::instance()->exportImage(autoExportActions(), outputUrl());
         setVideoMode(false);
     });
     connect(platform, &Platform::newScreensScreenshotTaken, this, [this](const QVector<CanvasImage> &screenImages) {
@@ -146,7 +152,7 @@ SpectacleCore::SpectacleCore(QObject *parent)
     // set up the export manager
     auto exportManager = ExportManager::instance();
     auto onImageExported = [this](const ExportManager::Actions &actions, const QUrl &url) {
-        if (Settings::quitAfterSaveCopyExport()) {
+        if (actions & ExportManager::UserAction && Settings::quitAfterSaveCopyExport()) {
             deleteWindows();
         }
 
@@ -215,7 +221,9 @@ SpectacleCore::SpectacleCore(QObject *parent)
             return window->screen() == screen;
         };
         auto it = std::find_if(m_captureWindows.begin(), m_captureWindows.end(), hasScreen);
-        m_captureWindows.erase(it);
+        if (it != m_captureWindows.end()) {
+            m_captureWindows.erase(it);
+        }
     });
 
     connect(m_videoPlatform.get(), &VideoPlatform::recordedTimeChanged, this, &SpectacleCore::recordedTimeChanged);
@@ -591,17 +599,12 @@ void SpectacleCore::showErrorMessage(const QString &message)
     }
 }
 
-void SpectacleCore::onScreenshotUpdated(const QImage &image, const ExportManager::Actions &actions)
+void SpectacleCore::onScreenshotUpdated(const QImage &image)
 {
-    using Option = CommandLineOptions::Option;
-    using Action = ExportManager::Action;
-
     m_annotationDocument->clearImages();
-
-    auto exportManager = ExportManager::instance();
-    exportManager->setImage(image);
     m_annotationDocument->addImage(image);
-    exportManager->updateTimestamp();
+    ExportManager::instance()->setImage(image);
+    ExportManager::instance()->updateTimestamp();
 
     if (m_startMode == StartMode::Gui) {
         if (image.isNull()) {
@@ -610,22 +613,13 @@ void SpectacleCore::onScreenshotUpdated(const QImage &image, const ExportManager
             return;
         }
         initViewerWindow(ViewerWindow::Image);
-        if (m_cliOptions[Option::EditExisting]) {
+        if (m_cliOptions[CommandLineOptions::EditExisting]) {
             ViewerWindow::instance()->setAnnotating(true);
         }
         ViewerWindow::instance()->setVisible(true);
         auto titlePreset = !image.isNull() ? SpectacleWindow::Unsaved : SpectacleWindow::Saved;
         SpectacleWindow::setTitleForAll(titlePreset);
     }
-
-    syncExportImage();
-    if (actions & Action::Save && m_cliOptions[Option::Output]) {
-        exportManager->exportImage(actions, m_outputUrl);
-    } else if (actions & Action::Save && m_cliOptions[Option::EditExisting]) {
-        exportManager->exportImage(actions, m_editExistingUrl);
-    } else {
-        exportManager->exportImage(actions, outputUrl());
-    }
 }
 
 void SpectacleCore::onScreenshotFailed()
@@ -652,6 +646,10 @@ static QVector<KNotification *> notifications;
 
 void SpectacleCore::doNotify(const ExportManager::Actions &actions, const QUrl &saveUrl)
 {
+    if (m_cliOptions[CommandLineOptions::NoNotify]) {
+        return;
+    }
+
     // ensure program stays alive until the notification finishes.
     if (!m_eventLoopLocker) {
         m_eventLoopLocker = std::make_unique<QEventLoopLocker>();
@@ -964,3 +962,27 @@ QString SpectacleCore::timeFromMilliseconds(qint64 milliseconds) const
     }
     return KFormat().formatDuration(milliseconds, options);
 }
+
+QStringList SpectacleCore::supportedVideoFormats() const
+{
+    return m_videoPlatform->suggestedExtensions();
+}
+
+void SpectacleCore::setVideoFormat(const QString &format)
+{
+    if (format == Settings::videoFormat()) {
+        return;
+    }
+
+    m_videoPlatform->setExtension(format);
+    Settings::setVideoFormat(m_videoPlatform->extension());
+
+    Q_EMIT videoFormatChanged(format);
+}
+
+QString SpectacleCore::videoFormat() const
+{
+    return m_videoPlatform->extension();
+}
+
+#include "moc_SpectacleCore.cpp"
